/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_platformplugin_wrapper.h"

// Extra includes
#include <QList>
#include <QPair>
#include <QStringList>
#include <abstractmediastream.h>
#include <objectdescription.h>
#include <pysideconversions.h>
#include <qbytearray.h>
#include <qicon.h>
#include <qobject.h>
#include <qurl.h>

using namespace Phonon;

// Native ---------------------------------------------------------

PlatformPluginWrapper::PlatformPluginWrapper() : Phonon::PlatformPlugin() {
    // ... middle
}

QString PlatformPluginWrapper::applicationName() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "applicationName"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.applicationName()' not implemented.");
        return QString();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.applicationName", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

QObject * PlatformPluginWrapper::createBackend()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createBackend"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.createBackend()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.createBackend", Shiboken::SbkType<QObject >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QObject * cppResult(Shiboken::Converter< ::QObject * >::toCpp(pyResult));
    return cppResult;
}

QObject * PlatformPluginWrapper::createBackend(const QString & library, const QString & version)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createBackend"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.createBackend()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QString >::toPython(library),
        Shiboken::Converter< QString >::toPython(version)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.createBackend", Shiboken::SbkType<QObject >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QObject * cppResult(Shiboken::Converter< ::QObject * >::toCpp(pyResult));
    return cppResult;
}

Phonon::AbstractMediaStream * PlatformPluginWrapper::createMediaStream(const QUrl & url, QObject * parent)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createMediaStream"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.createMediaStream()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QUrl >::toPython(url),
        Shiboken::Converter< ::QObject * >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::Phonon::AbstractMediaStream * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.createMediaStream", Shiboken::SbkType<Phonon::AbstractMediaStream >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    Phonon::AbstractMediaStream * cppResult(Shiboken::Converter< ::Phonon::AbstractMediaStream * >::toCpp(pyResult));
    return cppResult;
}

QList<QPair<QByteArray, QString > > PlatformPluginWrapper::deviceAccessListFor(const Phonon::AudioOutputDevice & arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QList<QPair<QByteArray, QString > >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "deviceAccessListFor"));
    if (py_override.isNull()) {
        gil.release();
        return this->::Phonon::PlatformPlugin::deviceAccessListFor(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Phonon::AudioOutputDevice >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QPair<QByteArray, QString > >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<QPair<QByteArray, QString > > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.deviceAccessListFor", "list", pyResult->ob_type->tp_name);
        return QList<QPair<QByteArray, QString > >();
    }
    QList<QPair<QByteArray, QString > > cppResult(Shiboken::Converter< ::QList<QPair<QByteArray, QString > > >::toCpp(pyResult));
    return cppResult;
}

QIcon PlatformPluginWrapper::icon(const QString & name) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QIcon();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "icon"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.icon()' not implemented.");
        return QIcon();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QIcon();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QIcon >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.icon", Shiboken::SbkType<QIcon >()->tp_name, pyResult->ob_type->tp_name);
        return QIcon();
    }
    QIcon cppResult(Shiboken::Converter< ::QIcon >::toCpp(pyResult));
    return cppResult;
}

bool PlatformPluginWrapper::isMimeTypeAvailable(const QString & mimeType) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isMimeTypeAvailable"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.isMimeTypeAvailable()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(mimeType)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.isMimeTypeAvailable", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

qreal PlatformPluginWrapper::loadVolume(const QString & outputName) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qreal(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "loadVolume"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.loadVolume()' not implemented.");
        return qreal(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(outputName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qreal(0);
    }
    // Check return type
    bool typeIsValid = PyFloat_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.loadVolume", "qreal", pyResult->ob_type->tp_name);
        return qreal(0);
    }
    qreal cppResult(Shiboken::Converter< double >::toCpp(pyResult));
    return cppResult;
}

void PlatformPluginWrapper::notification(const char * notificationName, const QString & text, const QStringList & actions, QObject * receiver, const char * actionSlot) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "notification"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.notification()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNNN)",
        Shiboken::Converter< const char * >::toPython(notificationName),
        Shiboken::Converter< QString >::toPython(text),
        Shiboken::Converter< ::QStringList >::toPython(actions),
        Shiboken::Converter< ::QObject * >::toPython(receiver),
        Shiboken::Converter< const char * >::toPython(actionSlot)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QList<int > PlatformPluginWrapper::objectDescriptionIndexes(Phonon::ObjectDescriptionType type) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QList<int >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "objectDescriptionIndexes"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.objectDescriptionIndexes()' not implemented.");
        return QList<int >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Phonon::ObjectDescriptionType >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<int >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<int > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.objectDescriptionIndexes", "list", pyResult->ob_type->tp_name);
        return QList<int >();
    }
    QList<int > cppResult(Shiboken::Converter< ::QList<int > >::toCpp(pyResult));
    return cppResult;
}

QHash<QByteArray, QVariant > PlatformPluginWrapper::objectDescriptionProperties(Phonon::ObjectDescriptionType type, int index) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QHash<QByteArray, QVariant >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "objectDescriptionProperties"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.objectDescriptionProperties()' not implemented.");
        return QHash<QByteArray, QVariant >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Ni)",
        Shiboken::Converter< ::Phonon::ObjectDescriptionType >::toPython(type),
        index
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QHash<QByteArray, QVariant >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QHash<QByteArray, QVariant > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "PlatformPlugin.objectDescriptionProperties", "hash", pyResult->ob_type->tp_name);
        return QHash<QByteArray, QVariant >();
    }
    QHash<QByteArray, QVariant > cppResult(Shiboken::Converter< ::QHash<QByteArray, QVariant > >::toCpp(pyResult));
    return cppResult;
}

void PlatformPluginWrapper::saveVolume(const QString & outputName, qreal volume)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "saveVolume"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.saveVolume()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nd)",
        Shiboken::Converter< QString >::toPython(outputName),
        volume
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

PlatformPluginWrapper::~PlatformPluginWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Phonon_PlatformPlugin_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::PlatformPlugin >()))
        return -1;

    PlatformPluginWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_PLATFORMPLUGIN_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'Phonon::PlatformPlugin' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // PlatformPlugin()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new PlatformPluginWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::PlatformPlugin >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_applicationName(PyObject* self)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // applicationName()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.applicationName()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const Phonon::PlatformPlugin*>(cppSelf)->applicationName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_createBackend(PyObject* self, PyObject* args)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto Sbk_Phonon_PlatformPluginFunc_createBackend_TypeError;

    if (!PyArg_UnpackTuple(args, "createBackend", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createBackend()
    // 1: createBackend(QString,QString)
    if (numArgs == 0) {
        overloadId = 0; // createBackend()
    } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // createBackend(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_createBackend_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // createBackend()
            {

                if(!PyErr_Occurred()) {
                    // createBackend()
                    if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.createBackend()' not implemented.");
                        return 0;
                    }
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QObject * cppResult = cppSelf->createBackend();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // createBackend(QString,QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // createBackend(QString,QString)
                    if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.createBackend()' not implemented.");
                        return 0;
                    }
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QObject * cppResult = cppSelf->createBackend(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_PlatformPluginFunc_createBackend_TypeError:
        const char* overloads[] = {"", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.PlatformPlugin.createBackend", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_createMediaStream(PyObject* self, PyObject* args)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createMediaStream", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createMediaStream(QUrl,QObject*)
    if (numArgs == 2 && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
        overloadId = 0; // createMediaStream(QUrl,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_createMediaStream_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QObject * cppArg1 = Shiboken::Converter<QObject * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // createMediaStream(QUrl,QObject*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.createMediaStream()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::AbstractMediaStream * cppResult = cppSelf->createMediaStream(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Phonon::AbstractMediaStream * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_PlatformPluginFunc_createMediaStream_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.PlatformPlugin.createMediaStream", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_deviceAccessListFor(PyObject* self, PyObject* arg)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: deviceAccessListFor(Phonon::AudioOutputDevice)const
    if (Shiboken::Converter< ::Phonon::AudioOutputDevice >::isConvertible(arg)) {
        overloadId = 0; // deviceAccessListFor(Phonon::AudioOutputDevice)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_deviceAccessListFor_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            Phonon::AudioOutputDevice cppArg0 = Shiboken::Converter<Phonon::AudioOutputDevice >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // deviceAccessListFor(Phonon::AudioOutputDevice)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QPair<QByteArray, QString > > cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const Phonon::PlatformPlugin*>(cppSelf)->::Phonon::PlatformPlugin::deviceAccessListFor(cppArg0) : const_cast<const Phonon::PlatformPlugin*>(cppSelf)->deviceAccessListFor(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QPair<QByteArray, QString > > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_PlatformPluginFunc_deviceAccessListFor_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::AudioOutputDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.PlatformPlugin.deviceAccessListFor", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_icon(PyObject* self, PyObject* arg)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: icon(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // icon(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_icon_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // icon(QString)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.icon()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = const_cast<const Phonon::PlatformPlugin*>(cppSelf)->icon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_PlatformPluginFunc_icon_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.PlatformPlugin.icon", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_isMimeTypeAvailable(PyObject* self, PyObject* arg)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isMimeTypeAvailable(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // isMimeTypeAvailable(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_isMimeTypeAvailable_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isMimeTypeAvailable(QString)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.isMimeTypeAvailable()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const Phonon::PlatformPlugin*>(cppSelf)->isMimeTypeAvailable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_PlatformPluginFunc_isMimeTypeAvailable_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.PlatformPlugin.isMimeTypeAvailable", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_loadVolume(PyObject* self, PyObject* arg)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: loadVolume(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // loadVolume(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_loadVolume_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // loadVolume(QString)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.loadVolume()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const Phonon::PlatformPlugin*>(cppSelf)->loadVolume(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_PlatformPluginFunc_loadVolume_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.PlatformPlugin.loadVolume", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_notification(PyObject* self, PyObject* args, PyObject* kwds)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.PlatformPlugin.notification(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.PlatformPlugin.notification(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:notification", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: notification(const char*,QString,QStringList,QObject*,const char*)const
    if (numArgs >= 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // notification(const char*,QString,QStringList,QObject*,const char*)const
        } else if (Shiboken::Converter< ::QStringList >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // notification(const char*,QString,QStringList,QObject*,const char*)const
            } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 0; // notification(const char*,QString,QStringList,QObject*,const char*)const
                } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[4])) {
                    overloadId = 0; // notification(const char*,QString,QStringList,QObject*,const char*)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_notification_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "actions");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "actions";
                    else if (Shiboken::Converter< ::QStringList >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_Phonon_PlatformPluginFunc_notification_TypeError;
                }
                value = PyDict_GetItemString(kwds, "receiver");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "receiver";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_Phonon_PlatformPluginFunc_notification_TypeError;
                }
                value = PyDict_GetItemString(kwds, "actionSlot");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "actionSlot";
                    else if (Shiboken::Converter< const char * >::isConvertible(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_Phonon_PlatformPluginFunc_notification_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.phonon.PlatformPlugin.notification(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QStringList cppArg2 = pyargs[2] ? Shiboken::Converter<QStringList >::toCpp(pyargs[2]) : QStringList();
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QObject * cppArg3 = pyargs[3] ? Shiboken::Converter<QObject * >::toCpp(pyargs[3]) : 0;
            const char * cppArg4 = pyargs[4] ? Shiboken::Converter<const char * >::toCpp(pyargs[4]) : 0;

            if(!PyErr_Occurred()) {
                // notification(const char*,QString,QStringList,QObject*,const char*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.notification()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const Phonon::PlatformPlugin*>(cppSelf)->notification(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_PlatformPluginFunc_notification_TypeError:
        const char* overloads[] = {"str, QString, list = QStringList(), PySide.QtCore.QObject = None, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.PlatformPlugin.notification", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_objectDescriptionIndexes(PyObject* self, PyObject* arg)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: objectDescriptionIndexes(Phonon::ObjectDescriptionType)const
    if (Shiboken::Converter< ::Phonon::ObjectDescriptionType >::isConvertible(arg)) {
        overloadId = 0; // objectDescriptionIndexes(Phonon::ObjectDescriptionType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_objectDescriptionIndexes_TypeError;

    // Call function/method
    {
        {
            Phonon::ObjectDescriptionType cppArg0 = Shiboken::Converter<Phonon::ObjectDescriptionType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // objectDescriptionIndexes(Phonon::ObjectDescriptionType)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.objectDescriptionIndexes()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<int > cppResult = const_cast<const Phonon::PlatformPlugin*>(cppSelf)->objectDescriptionIndexes(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<int > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_PlatformPluginFunc_objectDescriptionIndexes_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.ObjectDescriptionType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.PlatformPlugin.objectDescriptionIndexes", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_objectDescriptionProperties(PyObject* self, PyObject* args)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "objectDescriptionProperties", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: objectDescriptionProperties(Phonon::ObjectDescriptionType,int)const
    if (numArgs == 2 && Shiboken::Converter< ::Phonon::ObjectDescriptionType >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // objectDescriptionProperties(Phonon::ObjectDescriptionType,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_objectDescriptionProperties_TypeError;

    // Call function/method
    {
        {
            Phonon::ObjectDescriptionType cppArg0 = Shiboken::Converter<Phonon::ObjectDescriptionType >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // objectDescriptionProperties(Phonon::ObjectDescriptionType,int)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.objectDescriptionProperties()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHash<QByteArray, QVariant > cppResult = const_cast<const Phonon::PlatformPlugin*>(cppSelf)->objectDescriptionProperties(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHash<QByteArray, QVariant > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_PlatformPluginFunc_objectDescriptionProperties_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.ObjectDescriptionType, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.PlatformPlugin.objectDescriptionProperties", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_PlatformPluginFunc_saveVolume(PyObject* self, PyObject* args)
{
    Phonon::PlatformPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::PlatformPlugin* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "saveVolume", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: saveVolume(QString,qreal)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // saveVolume(QString,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_PlatformPluginFunc_saveVolume_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // saveVolume(QString,qreal)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'PlatformPlugin.saveVolume()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->saveVolume(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_PlatformPluginFunc_saveVolume_TypeError:
        const char* overloads[] = {"QString, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.PlatformPlugin.saveVolume", overloads);
        return 0;
}

static PyMethodDef Sbk_Phonon_PlatformPlugin_methods[] = {
    {"applicationName", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_applicationName, METH_NOARGS},
    {"createBackend", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_createBackend, METH_VARARGS},
    {"createMediaStream", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_createMediaStream, METH_VARARGS},
    {"deviceAccessListFor", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_deviceAccessListFor, METH_O},
    {"icon", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_icon, METH_O},
    {"isMimeTypeAvailable", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_isMimeTypeAvailable, METH_O},
    {"loadVolume", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_loadVolume, METH_O},
    {"notification", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_notification, METH_VARARGS|METH_KEYWORDS},
    {"objectDescriptionIndexes", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_objectDescriptionIndexes, METH_O},
    {"objectDescriptionProperties", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_objectDescriptionProperties, METH_VARARGS},
    {"saveVolume", (PyCFunction)Sbk_Phonon_PlatformPluginFunc_saveVolume, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_PlatformPlugin_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.Phonon.PlatformPlugin",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_PlatformPlugin_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_Phonon_PlatformPlugin_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_Phonon_PlatformPlugin(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_PLATFORMPLUGIN_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_PlatformPlugin_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_Phonon_PlatformPlugin_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_Phonon_PlatformPlugin_Type, &Shiboken::callCppDestructor<Phonon::PlatformPlugin >);
    if (PyType_Ready((PyTypeObject*)&Sbk_Phonon_PlatformPlugin_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_Phonon_PlatformPlugin_Type, "Phonon::PlatformPlugin*");
    PyDict_SetItemString(module,"PlatformPlugin", (PyObject*)&Sbk_Phonon_PlatformPlugin_Type);

    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::PlatformPlugin >("Phonon::PlatformPlugin*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::PlatformPlugin >("Phonon::PlatformPlugin$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::PlatformPlugin >(typeid(Phonon::PlatformPlugin).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::PlatformPlugin >(typeid(PlatformPluginWrapper).name());
    PySide::initQtMetaType< ::Phonon::PlatformPlugin* >();
}

